-- The following is an example of how to get love2d to display a
-- background image and have an animated torch on a PC DOS system using
-- LoveDOS. However, note that I am currently too lazy to actually
-- shrink the torch image and place it correctly in comparison to the
-- more modern version of this script.

-- A few notes before we begin...
--    1. Do not use images larger than 320x200; default window size is
--       320x200.
--    2. Do not use more than 256 colors; that also includes the
--       combined total of all of the images and sprites, so it may be
--       a good idea to stick with the same color palette for 
--       everything or use the GIF format with a 256 color paint 
--       program.
--    3. You cannot "get lazy" and try to use an animated GIF (89a) 
--       instead of a sprite sheet.
--    4. Keep all file names 8 characters with no more than three
--       characters for the file extension, giving a maximum total of
--       11 characters, or 12 if you count the period character.
--    5. Doing things like rotating sprites does not appear to work and
--       so it may be a good idea to open the background in an image
--       editor and load sprites on another layer, if possible, to see
--       how it would look before adding to the game. I have a feeling
--       that you will be doing a LOT of prerendering before adding
--       resources to your game if DOS is the target platform.

-- WARNING
-- This version is not compatible with modern LOVE. For whatever reason,
-- modern versions are very pick about "main.lua" versus "MAIN.LUA" and
-- does not like the GIF format and so you would need to either use JPEG
-- or PNG instead. GIF is used here because that was a common format
-- found during the later years of DOS computing and if your computer
-- does not have enough RAM to run GIF-supported paint programs for DOS,
-- you probably cannot use LoveDOS to make a game anyway.

local torch_fps = 10
local torch_x = 100
local torch_y = 100

local torch_anim_timer = 1/ torch_fps
local torch_frame = 1
local torch_num_frames = 5
local torch_first_frame_middle_pixel_x = 16
local torch_first_frame_middle_pixel_y = 16
local torch_frames_width = 32
local torch_frames_height = 32
local torch_xoffset

function love.load()
    backgroundimage = love.graphics.newImage("DUNGEON.GIF")
    torch_spritesheet = love.graphics.newImage("TORCH.GIF")
    torch_animation = love.graphics.newQuad(torch_first_frame_middle_pixel_x, torch_first_frame_middle_pixel_y, torch_frames_width, torch_frames_height, torch_spritesheet:getDimensions())
    
    music = love.audio.newSource('DUNGEON.WAV')
    music:setLooping( true )
    music:play()
end

function love.update(dt)
    if dt > 0.035 then return end
    torch_anim_timer = torch_anim_timer - dt
    if torch_anim_timer <= 0 then
        torch_anim_timer = 1 / torch_fps
        torch_frame = torch_frame + 1
        if torch_frame > torch_num_frames then torch_frame = 1 end
        torch_xoffset = 32 * torch_frame
        torch_animation:setViewport(torch_xoffset, 0,32,32)
    end
    
    if love.keyboard.isDown("q") then
        love.event.quit()
    end
    
end

function love.draw()
    love.graphics.draw(backgroundimage, 0, 0)
    love.graphics.draw(torch_spritesheet, torch_animation, torch_x, torch_y)
end
